@@ -38,8 +38,7 @@ import time
 import podcastparser
 
 import gpodder
-from gpodder import (coverart, escapist_videos, feedcore, registry, schema,
-                     util, vimeo, youtube)
+from gpodder import coverart, feedcore, registry, schema, util, vimeo, youtube
 
 logger = logging.getLogger(__name__)
 
@@ -183,37 +182,40 @@ class PodcastParserFeed(Feed):
             url = self.feed['paged_feed_next']
             logger.debug("get_next_page: feed has next %s", url)
             url = channel.authenticate_url(url)
-            res = self.fetcher.fetch(url, max_episodes=max_episodes)
-            if res.status == feedcore.UPDATED_FEED:
-                res.feed = PodcastParserFeed(res.feed, self.fetcher, max_episodes)
-            return res
+            return self.fetcher.fetch(url, autodiscovery=False, max_episodes=max_episodes)
         return None
 
 
 class gPodderFetcher(feedcore.Fetcher):
     """
-    This class extends the feedcore Fetcher with the gPodder User-Agent and the
-    Proxy handler based on the current settings in gPodder.
+    This class implements fetching a channel from custom feed handlers
+    or the default using podcastparser
     """
     def fetch_channel(self, channel, max_episodes):
         custom_feed = registry.feed_handler.resolve(channel, None, max_episodes)
         if custom_feed is not None:
             return custom_feed
+        # TODO: revisit authenticate_url: pass auth as kwarg
         # If we have a username or password, rebuild the url with them included
         # Note: using a HTTPBasicAuthHandler would be pain because we need to
         # know the realm. It can be done, but I think this method works, too
         url = channel.authenticate_url(channel.url)
-        res = self.fetch(url, channel.http_etag, channel.http_last_modified, max_episodes)
-        if res.status == feedcore.UPDATED_FEED:
-            res.feed = PodcastParserFeed(res.feed, self, max_episodes)
-        return res
+        return self.fetch(url, channel.http_etag, channel.http_last_modified, max_episodes=max_episodes)
 
     def _resolve_url(self, url):
         url = youtube.get_real_channel_url(url)
         url = vimeo.get_real_channel_url(url)
-        url = escapist_videos.get_real_channel_url(url)
         return url
 
+    def parse_feed(self, url, data_stream, headers, status, max_episodes=0, **kwargs):
+        try:
+            feed = podcastparser.parse(url, data_stream)
+            feed['url'] = url
+            feed['headers'] = headers
+            return feedcore.Result(status, PodcastParserFeed(feed, self, max_episodes))
+        except ValueError as e:
+            raise feedcore.InvalidFeed('Could not parse feed: {url}: {msg}'.format(url=url, msg=e))
+
 
 # Our podcast model:
 #
@@ -260,7 +262,7 @@ class PodcastEpisode(PodcastModelObject):
     MAX_FILENAME_LENGTH = 120  # without extension
     MAX_FILENAME_WITH_EXT_LENGTH = 140 - len(".partial.webm")  # with extension
 
-    __slots__ = schema.EpisodeColumns
+    __slots__ = schema.EpisodeColumns + ('_download_error',)
 
     def _deprecated(self):
         raise Exception('Property is deprecated!')
@@ -288,18 +290,26 @@ class PodcastEpisode(PodcastModelObject):
 
         audio_available = any(enclosure['mime_type'].startswith('audio/') for enclosure in entry['enclosures'])
         video_available = any(enclosure['mime_type'].startswith('video/') for enclosure in entry['enclosures'])
+        link_has_media = False
+        if not (audio_available or video_available):
+            _url = episode.url
+            episode.url = util.normalize_feed_url(entry['link'])
+            # Check if any extensions (e.g. youtube-dl) support the link
+            link_has_media = registry.custom_downloader.resolve(None, None, episode) is not None
+            episode.url = _url
+        media_available = audio_available or video_available or link_has_media
 
         for enclosure in entry['enclosures']:
             episode.mime_type = enclosure['mime_type']
 
             # Skip images in feeds if audio or video is available (bug 979)
             # This must (and does) also look in Media RSS enclosures (bug 1430)
-            if episode.mime_type.startswith('image/') and (audio_available or video_available):
+            if episode.mime_type.startswith('image/') and media_available:
                 continue
 
             # If we have audio or video available later on, skip
-            # 'application/octet-stream' data types (fixes Linux Outlaws)
-            if episode.mime_type == 'application/octet-stream' and (audio_available or video_available):
+            # all 'application/*' data types (fixes Linux Outlaws and peertube feeds)
+            if episode.mime_type.startswith('application/') and media_available:
                 continue
 
             episode.url = util.normalize_feed_url(enclosure['url'])
@@ -314,7 +324,7 @@ class PodcastEpisode(PodcastModelObject):
         if not episode.url:
             return None
 
-        if any(mod.is_video_link(episode.url) for mod in (youtube, vimeo, escapist_videos)):
+        if any(mod.is_video_link(episode.url) for mod in (youtube, vimeo)):
             return episode
 
         # Check if we can resolve this link to a audio/video file
@@ -325,6 +335,9 @@ class PodcastEpisode(PodcastModelObject):
         if file_type is not None:
             return episode
 
+        if link_has_media:
+            return episode
+
         return None
 
     def __init__(self, channel):
@@ -357,6 +370,8 @@ class PodcastEpisode(PodcastModelObject):
         # Timestamp of last playback time
         self.last_playback = 0
 
+        self._download_error = None
+
     @property
     def channel(self):
         return self.parent
@@ -398,7 +413,7 @@ class PodcastEpisode(PodcastModelObject):
         # "#001: Title" -> "001: Title"
         if (
                 not self.parent._common_prefix and
-                re.match('^#\d+: ', self.title) and
+                re.match(r'^#\d+: ', self.title) and
                 len(self.title) - 1 > LEFTOVER_MIN):
             return self.title[1:]
 
@@ -476,7 +491,7 @@ class PodcastEpisode(PodcastModelObject):
     def one_line_description(self):
         MAX_LINE_LENGTH = 120
         desc = util.remove_html_tags(self.description or '')
-        desc = re.sub('\s+', ' ', desc).strip()
+        desc = re.sub(r'\s+', ' ', desc).strip()
         if not desc:
             return _('No description available')
         else:
@@ -494,6 +509,7 @@ class PodcastEpisode(PodcastModelObject):
             gpodder.user_extensions.on_episode_delete(self, filename)
             util.delete_file(filename)
 
+        self._download_error = None
         self.set_state(gpodder.STATE_DELETED)
 
     def get_playback_url(self, config=None, allow_partial=False):
@@ -587,7 +603,6 @@ class PodcastEpisode(PodcastModelObject):
             # Use title for YouTube, Vimeo and Soundcloud downloads
             if (youtube.is_video_link(self.url) or
                     vimeo.is_video_link(self.url) or
-                    escapist_videos.is_video_link(self.url) or
                     episode_filename == 'stream'):
                 episode_filename = self.title
 
@@ -677,7 +692,7 @@ class PodcastEpisode(PodcastModelObject):
 
     def file_type(self):
         # Assume all YouTube/Vimeo links are video files
-        if youtube.is_video_link(self.url) or vimeo.is_video_link(self.url) or escapist_videos.is_video_link(self.url):
+        if youtube.is_video_link(self.url) or vimeo.is_video_link(self.url):
             return 'video'
 
         return util.file_type_by_extension(self.extension())
@@ -948,7 +963,7 @@ class PodcastChannel(PodcastModelObject):
     @classmethod
     def sort_key(cls, podcast):
         key = util.convert_bytes(podcast.title.lower())
-        return re.sub('^the ', '', key).translate(cls.UNICODE_TRANSLATE)
+        return re.sub(r'^the ', '', key).translate(cls.UNICODE_TRANSLATE)
 
     @classmethod
     def load(cls, model, url, create=True, authentication_tokens=None, max_episodes=0):
@@ -1006,7 +1021,7 @@ class PodcastChannel(PodcastModelObject):
 
     def _consume_updated_title(self, new_title):
         # Replace multi-space and newlines with single space (Maemo bug 11173)
-        new_title = re.sub('\s+', ' ', new_title).strip()
+        new_title = re.sub(r'\s+', ' ', new_title).strip()
 
         # Only update the podcast-supplied title when we
         # don't yet have a title, or if the title is the
@@ -1150,6 +1165,7 @@ class PodcastChannel(PodcastModelObject):
             if result.status == feedcore.UPDATED_FEED:
                 self._consume_updated_feed(result.feed, max_episodes)
             elif result.status == feedcore.NEW_LOCATION:
+                # FIXME: could return the feed because in autodiscovery it is parsed already
                 url = result.feed
                 logger.info('New feed location: %s => %s', self.url, url)
                 if url in set(x.url for x in self.model.get_podcasts()):
@@ -1213,7 +1229,7 @@ class PodcastChannel(PodcastModelObject):
         return self.section
 
     def _get_content_type(self):
-        if 'youtube.com' in self.url or 'vimeo.com' in self.url or 'escapistmagazine.com' in self.url:
+        if 'youtube.com' in self.url or 'vimeo.com' in self.url:
             return _('Video')
 
         audio, video, other = 0, 0, 0
