@@ -86,12 +86,17 @@ function extract_installer {
 PIP_REQUIREMENTS="\
 podcastparser==0.6.6
 mygpoclient==1.8
-git+https://github.com/enthought/pywin32-ctypes.git@f27d6a0
+git+https://github.com/jaraco/pywin32-ctypes.git@f27d6a0
 html5lib==1.1
 webencodings==0.5.1
 certifi==2020.11.8
 mutagen==1.45.1
-youtube_dl==2020.11.21.1
+youtube_dl
+requests==2.25.1
+urllib3==1.26.5
+chardet==4.0.0
+idna==3.1
+PySocks==1.7.1
 "
 
 function install_deps {
@@ -117,9 +122,8 @@ function install_deps {
     # replace ca-certificates with certifi's
     build_pacman --noconfirm -Rdds mingw-w64-"${ARCH}"-ca-certificates || true
     mkdir -p ${MINGW_ROOT}/ssl
-    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c))')
+    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c and ".local" not in c))')
     cp -v ${site_packages}/certifi/cacert.pem ${MINGW_ROOT}/ssl/cert.pem
-    build_pip uninstall -y certifi
 
     build_pacman --noconfirm -Rdds mingw-w64-"${ARCH}"-python3-pip || true
 }
@@ -144,8 +148,8 @@ function install_gpodder {
     GPO_VERSION_DESC="$GPO_VERSION"
     if [ "$1" = "master" ]
     then
-        local GIT_REV=$(git rev-list --count HEAD)
-        local GIT_HASH=$(git rev-parse --short HEAD)
+        local GIT_REV=$(cd "${REPO_CLONE}" && git rev-list --count HEAD)
+        local GIT_HASH=$(cd "${REPO_CLONE}" && git rev-parse --short HEAD)
         GPO_VERSION_DESC="$GPO_VERSION-rev$GIT_REV-$GIT_HASH"
     fi
 
@@ -155,7 +159,7 @@ function install_gpodder {
         "${GPO_VERSION}" "${MINGW_ROOT}"/bin
 
 	# install fake dbus
-    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c))')
+    site_packages=$(build_python -c  'import sys;print(next(c for c in sys.path if "site-packages" in c and ".local" not in c))')
     site_packages_unix=$(echo "/$site_packages" | sed -e 's/\\/\//g' -e 's/://')
     rsync -arv --delete "${REPO_CLONE}"/tools/fake-dbus-module/dbus "${site_packages_unix}/"
 	
@@ -438,7 +442,7 @@ function build_installer {
     cp "${REPO_CLONE}"/src/gpodder/build_info.py "$BUILDPY"
     echo 'BUILD_TYPE = u"windows"' >> "$BUILDPY"
     echo "BUILD_VERSION = $BUILD_VERSION" >> "$BUILDPY"
-    (cd "$REPO_CLONE" && echo "BUILD_INFO = u\"$(git rev-parse --short HEAD)\"" >> "$BUILDPY")
+    (cd "$REPO_CLONE" && echo "BUILD_INFO = u\"$(cd "${REPO_CLONE}" && git rev-parse --short HEAD)\"" >> "$BUILDPY")
     (cd $(dirname "$BUILDPY") && build_compileall -d "" -q -f -l .)
     rm -f "$BUILDPY"
 
@@ -453,7 +457,7 @@ function build_portable_installer {
     cp "${REPO_CLONE}"/src/gpodder/build_info.py "$BUILDPY"
     echo 'BUILD_TYPE = u"windows-portable"' >> "$BUILDPY"
     echo "BUILD_VERSION = $BUILD_VERSION" >> "$BUILDPY"
-    (cd "$REPO_CLONE" && echo "BUILD_INFO = u\"$(git rev-parse --short HEAD)\"" >> "$BUILDPY")
+    (cd "$REPO_CLONE" && echo "BUILD_INFO = u\"$(cd "${REPO_CLONE}" && git rev-parse --short HEAD)\"" >> "$BUILDPY")
     (cd $(dirname "$BUILDPY") && build_compileall -d "" -q -f -l .)
     rm -f "$BUILDPY"
 
